---
# SPDX-FileCopyrightText: 2024 Nicco Kunzmann and Open Web Calendar Contributors <https://open-web-calendar.quelltext.eu/>
#
# SPDX-License-Identifier: CC-BY-SA-4.0

comments: true
---

# New Website & Funding

As the Open Web Calendar is funded by [NLNet](https://nlnet.nl/project/OpenWebCalendar/),
it was also suggested to setup a website that shows how to use the calendar,
not only hosting the tool itself.

<!-- more -->

## Funding

[<img alt="Logo NLnet: abstract logo of four people seen from above" src="https://nlnet.nl/logo/banner.svg" height="50px" />](https://nlnet.nl/) [<img alt="Logo NGI Zero: letterlogo shaped like a tag" src="https://nlnet.nl/image/logos/NGI0Core_tag.svg" height="50px" />](https://nlnet.nl/core)

This project was funded in 2024 through the [NGI0 Core Fund](https://nlnet.nl/core), a fund established by [NLnet](https://nlnet.nl/) with financial support from the European Commission's [Next Generation Internet programme](https://ngi.eu/). You might be able to get funded, too!
